@@ -1,6 +1,6 @@
-# Copyright 1999-2004 Gentoo Technologies, Inc.
+# Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.51 2004/08/01 23:48:42 agriffis Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.62 2004/10/28 19:18:38 azarah Exp $
 
 # Check to see if this is a livecd, if it is read the commandline
 # this mainly makes sure $CDBOOT is defined if it's a livecd
@@ -9,8 +9,10 @@
 	livecd_read_commandline
 
 # Reset pam_console permissions
-[ -x /sbin/pam_console_apply -a ! -c /dev/.devfsd ] && \
+if [ -x /sbin/pam_console_apply ] && [ ! -c /dev/.devfsd ]
+then
 	/sbin/pam_console_apply -r
+fi
 
 # We need to properly terminate devfsd to save the permissions
 if [ -n "`ps --no-heading -C 'devfsd'`" ]
@@ -18,13 +20,39 @@ then
 	ebegin "Stopping devfsd"
 	killall -15 devfsd &>/dev/null
 	eend $?
-elif [ ! -e /dev/.devfsd -a -e /dev/.udev -a "${RC_DEVICE_TARBALL}" = "yes" ] 
+elif [ ! -e /dev/.devfsd -a -e /dev/.udev \
+       -a "${RC_DEVICE_TARBALL}" = "yes" -a -z "${CDBOOT}" ]
 then
 	ebegin "Saving device nodes"
-	cd /dev
-	try tar -jclpf "/tmp/devices-$$.tar.bz2" *
-	try mv -f "/tmp/devices-$$.tar.bz2" /lib/udev-state/devices.tar.bz2
-	eend 0
+	# Handle our temp files
+	devices_udev="`mktemp /tmp/devices.udev.XXXXXX`"
+	devices_real="`mktemp /tmp/devices.real.XXXXXX`"
+	device_tarball="`mktemp /tmp/devices-XXXXXX`"
+	
+	if [ -z "${devices_udev}" -o -z "${devices_real}" -o \
+	     -z "${device_tarball}" ]
+	then
+		eend 1 "Could not create temporary files!"
+	else
+		cd /dev
+		# Find all devices
+		find . -xdev -type b -or -type c -or -type l | cut -d/ -f2- > \
+			"${devices_real}"
+		# Figure out what udev created
+		udevinfo -d | awk '/^N|S: ..*/ { i=1; while (i++<NF) { print $i}}' > \
+			"${devices_udev}"
+		# These ones we also do not want in there
+		for x in MAKEDEV core fd initctl pts shm sndstat stderr stdin stdout
+		do
+			echo "${x}" >> "${devices_udev}"
+		done
+		# Now only tarball those not created by udev
+		try tar -jclpf "${device_tarball}" \
+		        `fgrep -x -v -f "${devices_udev}" < "${devices_real}"`
+		try mv -f "${device_tarball}" /lib/udev-state/devices.tar.bz2
+		try rm -f "${devices_udev}" "${devices_real}"
+		eend 0
+	fi
 fi
 
 # Try to unmount all tmpfs filesystems not in use, else a deadlock may
@@ -58,7 +86,7 @@ remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mou
 [ -n "${remaining}" ] && {
 	sig=
 	retry=3
-	
+
 	while [ -n "${remaining}" -a "${retry}" -gt 0 ]
 	do
 		if [ "${retry}" -lt 3 ]
@@ -71,7 +99,7 @@ remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mou
 			umount -d ${remaining} &>/dev/null
 			eend $? "Failed to unmount filesystems"
 		fi
-		
+
 		remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mounts | \
 		            sort -r | grep -v '/newroot' | grep -v '/mnt/livecd'`"
 		[ -z "${remaining}" ] && break
@@ -92,8 +120,8 @@ no_unmounts="`mount | awk '{ if (($5 ~ /^(proc|sysfs|devfs|tmpfs|usb(dev)?fs)$/)
                                 ($1 ~ /^(rootfs|\/dev\/root)$/) ||
                                 ($3 == "/"))
                            print $3
-                       }' | sort | uniq`"
-for x in `awk '{ print $2 }' /proc/mounts | sort -r | uniq`
+                       }' | sort -u`"
+for x in `awk '{ print $2 }' /proc/mounts | sort -ru`
 do
 	do_unmount="yes"
 
@@ -103,16 +131,15 @@ do
 	then
 		continue
 	fi
-	
+
 	for y in ${no_unmounts}
 	do
 		[ "${x}" = "${y}" ] && do_unmount="no"
 	done
-	
+
 	if [ "${do_unmount}" = "yes" ]
 	then
 		umount "${x}" &>/dev/null || {
-		
 			# Kill processes still using this mount
 			/bin/fuser -k -m -9 "${x}" &>/dev/null
 			sleep 2
@@ -123,6 +150,37 @@ do
 done
 eend 0
 
+# Try to remove any dm-crypt mappings
+
+if [ -f /etc/conf.d/cryptfs ] && [ -x /bin/cryptsetup ]
+then
+	einfo "Removing dm-crypt mappings"
+
+	/bin/egrep "^(mount|swap)" /etc/conf.d/cryptfs | \
+	while read mountline
+	do
+		mount=
+		swap=
+		target=
+
+		eval ${mountline}
+
+		if [ -n "${mount}" ]
+		then
+			target=${mount}
+		elif [ -n "${swap}" ]
+		then
+			target=${swap}
+		else
+			ewarn "Invalid line in /etc/conf.d/cryptfs: ${mountline}"
+		fi
+
+		ebegin "Removing dm-crypt mapping for: ${target}"
+		/bin/cryptsetup remove ${target}
+		eend $? "Failed to remove dm-crypt mapping for: ${target}"
+	done
+fi
+
 # Stop LVM
 if [ -x /sbin/vgchange ] && [ -f /etc/lvmtab -o -d /etc/lvm ] && \
    [ -d /proc/lvm  -o "`grep device-mapper /proc/misc 2>/dev/null`" ]
@@ -148,7 +206,7 @@ ups_kill_power() {
 mount_readonly() {
 	local x=
 	local retval=0
-	
+
 	for x in `awk '$1 != "none" { print $2 }' /proc/mounts | sort -r`
 	do
 		# ${x} needs to be quoted to handle octal sequences such as
