@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.40 2004/10/31 12:26:32 azarah Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.41 2004/11/04 16:20:25 uberlord Exp $
 
 # Common functions
 [ "${RC_GOT_FUNCTIONS}" != "yes" ] && source /sbin/functions.sh
@@ -276,7 +276,7 @@ svc_start() {
 							# Only worry about a net.* service if we do not have one
 							# up and running already, or if RC_NET_STRICT_CHECKING
 							# is set ....
-							if is_net_up
+							if ! is_net_up
 							then
 								startfail="yes"
 							fi
